==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/LinksPoll.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksPollPoll;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksPoll
 */
@JsonPropertyOrder({ LinksPoll.JSON_PROPERTY_POLL })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksPoll implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_POLL = "poll";
    private LinksPollPoll poll;

    public LinksPoll() {
    }

    public LinksPoll poll(LinksPollPoll poll) {

        this.poll = poll;
        return this;
    }

    /**
     * Get poll
     *
     * @return poll
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_POLL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksPollPoll getPoll() {
        return poll;
    }

    @JsonProperty(JSON_PROPERTY_POLL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPoll(LinksPollPoll poll) {
        this.poll = poll;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksPoll linksPoll = (LinksPoll) o;
        return Objects.equals(this.poll, linksPoll.poll);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(poll);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksPoll {\n");
        sb.append("    poll: ").append(toIndentedString(poll)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/LinksPoll.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksPollPoll;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksPoll
 */
@JsonPropertyOrder({ LinksPoll.JSON_PROPERTY_POLL })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksPoll implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_POLL = "poll";
    private LinksPollPoll poll;

    public LinksPoll() {
    }

    public LinksPoll poll(LinksPollPoll poll) {

        this.poll = poll;
        return this;
    }

    /**
     * Get poll
     *
     * @return poll
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_POLL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksPollPoll getPoll() {
        return poll;
    }

    @JsonProperty(JSON_PROPERTY_POLL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPoll(LinksPollPoll poll) {
        this.poll = poll;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksPoll linksPoll = (LinksPoll) o;
        return Objects.equals(this.poll, linksPoll.poll);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(poll);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksPoll {\n");
        sb.append("    poll: ").append(toIndentedString(poll)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
